@@ -395,7 +395,7 @@ def chrome_login(login_dict):
     if login_done is False:
         driver.get(login_url)
         if username_login_button_el is not None:
-            wait_find_element(driver, "//li[text()='账密登录']").click()
+            wait_find_element(driver, "//*[text()='账密登录']").click()
         wait_find_element(driver, username_el).clear()
         wait_find_element(driver, username_el).send_keys(username)
         wait_find_element(driver, password_el).clear()
