@@ -3,10 +3,21 @@
 # @Time : 2020/5/25 17:05
 # @Author : yangpingyan@gmail.com
 import sqlalchemy
-
+import os
 import numpy as np
 import matplotlib.pyplot as plt
 
+
+def append_to_csv(df, csv_file):
+    # 当df没有数据或只有列名时， 不做任何操作
+    if len(df) < 1:
+        print("No data saved")
+        return
+    if os.path.exists(csv_file):
+        df.to_csv(csv_file, index=False, header=False, mode='a', encoding='utf_8_sig')
+    else:
+        df.to_csv(csv_file, index=False, encoding='utf_8_sig')
+
 def kelly_formula_stock():
     probability_win = 0.7
     probability_loss = 1 - probability_win
